# daumdict
daumdict is a Python library for translating English into Korean using [Daum dictionary](https://dic.daum.net/).

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install daumdict.

```bash
pip install daumdict
```

## Usage
```
python3 d en plate # plate: 1.판 2.플레이트 3.접시 4.번호판 5.지각판
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)
